#!/bin/bash

# setup paths and environment to run AGILE and Rivet
set_environment () {
  echo "Setting environment..."
  
  # assume "x86_64-slc5-gcc43-opt" platform:
  LCG_PLATFORM=x86_64-slc5-gcc43-opt
  source /afs/cern.ch/sw/lcg/contrib/gcc/4.3/$LCG_PLATFORM/setup.sh
  
  local MCGENERATORS=/afs/cern.ch/sw/lcg/external/MCGenerators
  MCGENERATORS_HEPMC206=/afs/cern.ch/sw/lcg/external/MCGenerators_hepmc20603
  local AGILE=$MCGENERATORS_HEPMC206/agile/1.2.0/$LCG_PLATFORM
  local RIVET=$MCGENERATORS_HEPMC206/rivet/1.3.0/$LCG_PLATFORM
  HEPMC=/afs/cern.ch/sw/lcg/external/HepMC/2.06.03/$LCG_PLATFORM
  local PYTHON=/afs/cern.ch/sw/lcg/external/Python/2.6.5/$LCG_PLATFORM
  
  export PYTHONPATH=$AGILE/lib/python2.5/site-packages:$RIVET/lib/python2.6/site-packages:$PYTHONPATH
  export LD_LIBRARY_PATH=$HEPMC/lib:$AGILE/lib:$RIVET/lib:$PYTHON/lib:$LD_LIBRARY_PATH
  export PATH=$PYTHON/bin:$RIVET/bin:$AGILE/bin:$PATH
  export AGILE_GEN_PATH=$MCGENERATORS
  export AGILE_PARAM_PATH=$(pwd)/configuration
  export RIVET_REF_PATH=$(rivet-config --datadir)
  
  echo "LCG_PLATFORM=$LCG_PLATFORM"
  echo "gcc version = $(gcc -dumpversion)"
  echo "AGILE=$AGILE"
  echo "RIVET=$RIVET"
  echo "HEPMC=$HEPMC"
  echo "AGILE_GEN_PATH=$AGILE_GEN_PATH"
  echo "AGILE_PARAM_PATH=$AGILE_PARAM_PATH"
  echo "RIVET_REF_PATH=$RIVET_REF_PATH"
  echo ""
}


set_environment


# compile generator wrapper
PYTHIA8=$MCGENERATORS_HEPMC206/pythia8/142/$LCG_PLATFORM
make clean
make HEPMC=$HEPMC PYTHIA8=$PYTHIA8
export PYTHIA8DATA=$PYTHIA8/xmldoc
./pythia8.exe pythia8.params generator.hepmc


rivet -l 0 -a CDF_1988_S1865951 -a CDF_1990_S2089246 -a CDF_2002_S4796047 -H generator.aida generator.hepmc

